@@ -3,7 +3,7 @@ from rest_framework.decorators import action
 from rest_framework.request import Request
 from rest_framework.response import Response
 
-from django_large_image import utilities
+from django_large_image import tilesource
 from django_large_image.rest import params
 from django_large_image.rest.core import BaseLargeImageView
 
@@ -16,12 +16,8 @@ class MetaData(BaseLargeImageView):
     )
     @action(detail=True)
     def metadata(self, request: Request, pk: int) -> Response:
-        tile_source = self._get_tile_source(request, pk)
-        metadata = tile_source.getMetadata()
-        metadata.setdefault('geospatial', False)
-        if metadata['geospatial']:
-            bounds = utilities.get_tile_bounds(tile_source)
-            metadata['bounds'] = bounds
+        source = self._get_tile_source(request, pk)
+        metadata = tilesource.get_metadata(source)
         return Response(metadata)
 
     """Returns additional known metadata about the tile source."""
@@ -33,12 +29,8 @@ class MetaData(BaseLargeImageView):
     )
     @action(detail=True)
     def internal_metadata(self, request: Request, pk: int) -> Response:
-        tile_source = self._get_tile_source(request, pk)
-        metadata = tile_source.getInternalMetadata()
-        metadata.setdefault('geospatial', False)
-        if metadata['geospatial']:
-            bounds = utilities.get_tile_bounds(tile_source)
-            metadata['bounds'] = bounds
+        source = self._get_tile_source(request, pk)
+        metadata = tilesource.get_internal_metadata(source)
         return Response(metadata)
 
     @swagger_auto_schema(
@@ -48,8 +40,8 @@ class MetaData(BaseLargeImageView):
     )
     @action(detail=True)
     def bands(self, request: Request, pk: int) -> Response:
-        tile_source = self._get_tile_source(request, pk)
-        metadata = tile_source.getBandInformation()
+        source = self._get_tile_source(request, pk)
+        metadata = source.getBandInformation()
         return Response(metadata)
 
     @swagger_auto_schema(
@@ -63,6 +55,6 @@ class MetaData(BaseLargeImageView):
     @action(detail=True)
     def band(self, request: Request, pk: int) -> Response:
         band = int(request.query_params.get('band', 1))
-        tile_source = self._get_tile_source(request, pk)
-        metadata = tile_source.getOneBandInformation(band)
+        source = self._get_tile_source(request, pk)
+        metadata = source.getOneBandInformation(band)
         return Response(metadata)
